#
# spec file for package perl-Spreadsheet-ParseExcel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Spreadsheet-ParseExcel
Name:           perl-Spreadsheet-ParseExcel
Version:        0.660.0
Release:        2.3
%define cpan_version 0.66
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Read information from an Excel file
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JM/JMCNAMARA/%{cpan_name}-%{cpan_version}.tar.gz
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Crypt::RC4)
BuildRequires:  perl(Digest::Perl::MD5)
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(OLE::Storage_Lite) >= 0.19
Requires:       perl(Crypt::RC4)
Requires:       perl(Digest::Perl::MD5)
Requires:       perl(IO::Scalar)
Requires:       perl(OLE::Storage_Lite) >= 0.19
Provides:       perl(Spreadsheet::ParseExcel) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Cell) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Dump) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::FmtDefault) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::FmtJapan) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::FmtJapan2) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::FmtUnicode) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Font) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Format) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::SaveParser) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::SaveParser::Workbook) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::SaveParser::Worksheet) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Utility) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Workbook) = %{version}
Provides:       perl(Spreadsheet::ParseExcel::Worksheet) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The Spreadsheet::ParseExcel module can be used to read information from
Excel 95-2003 binary files.

The module cannot read files in the Excel 2007 Open XML XLSX format. See
the Spreadsheet::XLSX module instead.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CP932Excel.map examples README README_Japan.htm

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Dec 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.66
  see /usr/share/doc/packages/perl-Spreadsheet-ParseExcel/Changes
  0.66 December 29 2023
  ! Fix for CVE-2023-7101 [bsc#1218414]
    https://github.com/runrig/spreadsheet-parseexcel/issues/33
  * Unvalidated input can lead to arbitrary code execution.
  * https://github.com/runrig/spreadsheet-parseexcel/issues/33
* Sat Mar 22 2014 coolo@suse.com
- updated to 0.65
    ! Merge support for accessing hyperlink data
  0.64 March 11 2014
    ! RT #47072 (ExcelLocaltime rounding)
    http://rt.cpan.org/Public/Bug/Display.html?id=47072
    ! RT #93142 (date format w/commas)
    http://rt.cpan.org/Public/Bug/Display.html?id=93142
    ! RT #93651 (Update metadata)
    http://rt.cpan.org/Public/Bug/Display.html?id=93651
  0.63 March 7 2014
    ! RT #12946 (IO::Wrap)
    http://rt.cpan.org/Public/Bug/Display.html?id=12946
    ! RT #93065 (auto color)
    http://rt.cpan.org/Public/Bug/Display.html?id=93065
  0.62
    ! Fix test 46 skip_all plan logic.
    From CPAN testers.
    ! RT #52830 (0x00 general fmt) && fix test.
    http://rt.cpan.org/Public/Bug/Display.html?id=52830
    ! RT #93138 (undefined value as ARRAY)
    http://rt.cpan.org/Public/Bug/Display.html?id=93138
* Mon Jun  6 2011 coolo@novell.com
- updated to 0.59
  + Patch for decryption of default encrypted workbooks from
    Alexey Mazurin.
  ! Fix for invalid formatting of text cell that are numeric.
    http://rt.cpan.org/Public/Bug/Display.html?id=62073
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Oct 17 2010 chris@computersalat.de
- update to 0.58
  o Fix for text cells formatted with a leading apostrophe.
    http://rt.cpan.org/Public/Bug/Display.html?id=61299
  o Documentation fixes. Thanks to Dan Dascalescu
    Fix RT #61320 (typos)
    http://rt.cpan.org/Public/Bug/Display.html?id=61320
  o Fix for currency locales in format strings.
    Reported by wjaguar.
    http://rt.cpan.org/Public/Bug/Display.html?id=60547
  o Fix for incomplete SETUP records.
    Reported by M.C. Deurloo.
* Mon Aug 16 2010 chris@computersalat.de
- added Author
* Thu Aug 12 2010 kai.blin@gmail.com
- initial package 0.57
  * created by cpanspec 1.78
